JsonWebTokenCredential

Struct JsonWebTokenCredential 

pub struct JsonWebTokenCredential { /* private fields */ }
Credential wrapping a JWT (JSON Web Token).

From a private secret or private key, this will create short-lived tokens in JWT format. The credential can be used indefintely, but the underlying token will be rotated before it expires.

Implementations

Source

impl JsonWebTokenCredential

pub fn new(header: Header, key: EncodingKey, expiration: Duration) -> Self

Create a JWT credential with specific properties.

The header and key parameters are set as for jsonwebtoken.

The expiration parameter controls how long the token will be valid. Endpoints may restrict tokens to a maximum lifetime. Tokens are rotated after half the expiration time, to ensure that they have a reasonable remaining time to be used.

pub fn with_issuer(self, issuer: impl Into<Cow<'static, str>>) -> Self